###########################################################################################################
#
#  dropIt
#  
#  @author simon jokuschies
#  @version 1.0
#  @contact info@leafpictures.de
#  @website www.leafpictures.de
#  @plugin: www.leafpictures.de/dropIt  
#
#  description:
#  intuitive deleting nodes: delete selected nodes by
#  just dragging them to the bottom of the screen - like in flame
#
#  instalation
#
#  put dropIt folder in nuke home directory
#  in init.py add this line (without "#"):
#
#  nuke.pluginAddPath("dropIt")
#
##########################################################################################################

#  delete selected nodes if mousepositionY > (screenHeight - dropTollerance)
#  meaning the bigger the dropTollerance the earlier the selected nodes
#  get deleted if the mouse goes to the bottom of the screen
#  usually no need to change it. But if you like you can start the
#  deleting process earlier.
global dropTollerance
dropTollerance=10

# no need to change anything from here. Change only if you exactly know what you're doing

from PySide import QtGui, QtCore
import sys
import nuke

def initDropIt():
	'''
	initDropIt
	get screen resolution
	'''
	global maxH

	try:
		app = QtGui.QApplication(sys.argv)
	except:
		app = QtCore.QCoreApplication.instance()

	screenHeight = app.desktop().screenGeometry().height()
	maxH=screenHeight-dropTollerance
	
def dropIt():
	'''
	dropIt
	check for screen position; if mouse.y > screenheight-tollerance then delete selected nodes
	'''
	y= QtGui.QCursor.pos().y()

	if y>maxH:
		for node in nuke.selectedNodes():
			nuke.delete(node)
	
nuke.addKnobChanged(dropIt)
initDropIt()

